@@ -138,6 +138,7 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #define OPT_LS_RAINBOW       "ls-rainbow"
 #define OPT_LS_SYNTAX        "ls-syntax"
 #define OPT_LS_DELAY         "ls-delay"
+#define OPT_LS_LEGACY        "ls-legacy"
 #define OPT_LS_SYNTAX_ERROR  "ls-syntax-error"
 
 /// handle command line options
@@ -354,15 +355,18 @@ public:
     /** \return false  */
     bool isLsRainbow () const;
 
-    /** \return false  */
+    /** \return true if the LSP semantic highlighting features should be used */
     bool isLsSemantic () const;
 
-    /** \return false  */
+    /** \return true if the LSP hover features should be used  */
     bool isLsHover () const;
 
-    /** \return false  */
+    /** \return true if the LSP error message features should be used  */
     bool isLsSyntaxError () const;
 
+    /** \return true if the LSP server does not support capabilities report  */
+    bool isLsLegacy() const;
+
     /** \return max. input file size (default 256 MB) */
     off_t getMaxFileSize() const;
 
@@ -543,6 +547,7 @@ private:
     bool opt_ls_semantic;
     bool opt_ls_rainbow;
     bool opt_ls_syntax_error;
+    bool opt_ls_legacy;
 
     off_t maxFileSize;
 
