@@ -1,5 +1,5 @@
 // ASEnhancer.cpp
-// Copyright (c) 2018 by Jim Pattee <jimp03@email.com>.
+// Copyright (c) 2023 The Artistic Style Authors.
 // This code is licensed under the MIT License.
 // License.md describes the conditions under which this software may be distributed.
 
@@ -202,16 +202,13 @@ size_t ASEnhancer::findCaseColon(const string& line, size_t caseIndex) const
 				i++;
 				continue;
 			}
-			else if (line[i] == quoteChar_)          // check ending quote
+			if (line[i] == quoteChar_)          // check ending quote
 			{
 				isInQuote_ = false;
 				quoteChar_ = ' ';
 				continue;
 			}
-			else
-			{
-				continue;                           // must close quote before continuing
-			}
+			continue;                           // must close quote before continuing
 		}
 		if (line[i] == '"' 		// check opening quote
 		        || (line[i] == '\'' && !isDigitSeparator(line, i)))
@@ -294,8 +291,8 @@ bool ASEnhancer::isBeginDeclareSectionSQL(const string& line, size_t index) cons
 		if (!isCharPotentialHeader(line, i))
 			continue;
 		word = getCurrentWord(line, i);
-		for (size_t j = 0; j < word.length(); j++)
-			word[j] = (char) toupper(word[j]);
+		for (char& character : word)
+			character = (char) toupper(character);
 		if (word == "EXEC" || word == "SQL")
 		{
 			i += word.length() - 1;
@@ -343,8 +340,8 @@ bool ASEnhancer::isEndDeclareSectionSQL(const string& line, size_t index) const
 		if (!isCharPotentialHeader(line, i))
 			continue;
 		word = getCurrentWord(line, i);
-		for (size_t j = 0; j < word.length(); j++)
-			word[j] = (char) toupper(word[j]);
+		for (char& character : word)
+			character = (char) toupper(character);
 		if (word == "EXEC" || word == "SQL")
 		{
 			i += word.length() - 1;
@@ -512,7 +509,7 @@ void ASEnhancer::parseCurrentLine(string& line, bool isInPreprocessor, bool isIn
 				shouldUnindentComment = true;
 			break;                 // finished with the line
 		}
-		else if (!(isInComment) && line.compare(i, 2, "/*") == 0)
+		if (!(isInComment) && line.compare(i, 2, "/*") == 0)
 		{
 			// unindent if not in case braces
 			if (sw.switchBraceCount == 1 && sw.unindentCase)
@@ -525,7 +522,7 @@ void ASEnhancer::parseCurrentLine(string& line, bool isInPreprocessor, bool isIn
 				i = commentEnd - 1;
 			continue;
 		}
-		else if ((isInComment) && line.compare(i, 2, "*/") == 0)
+		if ((isInComment) && line.compare(i, 2, "*/") == 0)
 		{
 			// unindent if not in case braces
 			if (sw.switchBraceCount == 1 && sw.unindentCase)
@@ -534,7 +531,6 @@ void ASEnhancer::parseCurrentLine(string& line, bool isInPreprocessor, bool isIn
 			i++;
 			continue;
 		}
-
 		if (isInComment)
 		{
 			// unindent if not in case braces
@@ -573,19 +569,16 @@ void ASEnhancer::parseCurrentLine(string& line, bool isInPreprocessor, bool isIn
 
 		if (isPotentialKeyword)
 		{
-			for (size_t j = 0; j < indentableMacros->size(); j++)
+			for (const auto* indentableMacro : *indentableMacros)
 			{
 				// 'first' is the beginning macro
-				if (findKeyword(line, i, indentableMacros->at(j)->first))
+				if (findKeyword(line, i, indentableMacro->first))
 				{
 					nextLineIsEventIndent = true;
 					break;
 				}
-			}
-			for (size_t j = 0; j < indentableMacros->size(); j++)
-			{
 				// 'second' is the ending macro
-				if (findKeyword(line, i, indentableMacros->at(j)->second))
+				if (findKeyword(line, i, indentableMacro->second))
 				{
 					isInEventTable = false;
 					eventPreprocDepth = 0;
