@@ -2,7 +2,7 @@
                           codegenerator.cpp  -  description
                              -------------------
     begin                : Die Jul 9 2002
-    copyright            : (C) 2002-2021 by Andre Simon
+    copyright            : (C) 2002-2023 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -1278,6 +1278,19 @@ void CodeGenerator::initASStream() {
         if (streamIterator) delete streamIterator;
         streamIterator =  new astyle::ASStreamIterator ( in );
         formatter->init ( streamIterator );
+
+        if (currentSyntax->getDescription()=="C#") {
+		    formatter->setSharpStyle();
+	    } else if (currentSyntax->getDescription()=="Java") {
+		    formatter->setJavaStyle();
+	    } else if (currentSyntax->getDescription()=="Javascript") {
+		    formatter->setJSStyle();
+	    } else if (currentSyntax->getDescription()=="Objective C") {
+    		formatter->setObjCStyle();
+        } else {
+            formatter->setCStyle();
+        }
+
     }
 }
 
